@@ -36,7 +36,7 @@ class dummy(object):
    pass
 
 pathTmplDict = { 'CORDEX':'%(project)s/%(product)s/%(domain)s/%(institute)s/%(driving_model)s/%(experiment)s/%(ensemble)s/%(model)s/%(model_version)s/%(frequency)s/%(variable)s/files/%%(version)s/',   \
-                 'SPECS':'%(project)s/%(product)s/%(institute)s/%(model)s/%(experiment)s_%(series)s/%(start_date)s/%(frequency)s/%(realm)s/%(variable)s/%(ensemble)s/files/%%(version)s/', \
+                 'SPECS':'%(project)s/%(product)s/%(institute)s/%(model)s/%(experiment)s_%(series)s/%(start_date)s/%(frequency)s/%(realm)s/%(table)s/%(variable)s/%(ensemble)s/files/%%(version)s/', \
                  'CMIP5':'%(project)s/%(product)s/%(institute)s/%(model)s/%(experiment)s/%(frequency)s/%(realm)s/%(table)s/%(ensemble)s/files/%%(version)s/%(variable)s/', \
                  '__def__':'%(project)s/%(product)s/%(institute)s/%(model)s/%(experiment)s/%(frequency)s/%(realm)s/%(variable)s/%(ensemble)s/files/%%(version)s/', \
                }
@@ -210,20 +210,27 @@ class c4_init(object):
     self.project = "CORDEX"
     self.holdExceptions = False
     forceLogOrg = None
+    argsIn = args[:]
 
     # The --copy-config option must be the first argument if it is present.
     if args[0] == '--copy-config':
+       if len(args) < 2:
+         self.commandHints( argsIn )
        args.pop(0)
        dest_dir = args.pop(0)
        config.copy_config(dest_dir)
        print 'Configuration directory copied to %s.  Set CC_CONFIG_DIR to use this configuration.' % dest_dir
        print
        raise SystemExit(0)
+    elif args[0] == '-h':
+       print 'Help command not implemented yet'
+       raise SystemExit(0)
 
     self.summarymode = args[0] == '--sum'
     if self.summarymode:
       return
 
+    argu = []
     while len(args) > 0:
       next = args.pop(0)
       if next == '-f':
@@ -268,8 +275,11 @@ class c4_init(object):
         self.project = args.pop(0)
       else:
        print 'Unused argument: %s' % next
+       argu.append( next )
        nn+=1
-    assert nn==0, 'Aborting because of unused arguments'
+    if nn != 0:
+      print 'Unused arguments: ', argu
+      self.commandHints( argsIn )
 
     if self.project == 'CMIP5':
       fl0 = []
@@ -348,6 +358,22 @@ class c4_init(object):
           self.attributeMappings.append( ('am001',cl, string.split(bb[1],'=') ) )
       self.attributeMappingsLog = open( 'attributeMappingsLog.txt', 'w' )
 
+  def commandHints(self, args):
+    if args[0] in ['-h','--sum']:
+      print 'Arguments look OK'
+    elif args[0] == '--copy-config':
+      print 'Usage [configuration copy]: ceda_cc --copy-config <target directory path>'
+    else:
+      if not( '-f' in args or '-d' in args or '-D' in args):
+        print 'No file or target directory specified'
+        print """USAGE:
+ceda_cc -p <project> [-f <NetCDF file>|-d <directory containing files>|-D <root of directory tree>] [other options]
+
+With the "-D" option, all files in the directory tree beneath the given diretory will be checked. With the "-d" option, only files in the given directory will be checked.
+"""
+    raise SystemExit(0)
+   
+
   def getFileLog( self, fn, flf=None ):
     if flf == None:
       tstring2 = '%4.4i%2.2i%2.2i' % time.gmtime()[0:3]
@@ -480,7 +506,7 @@ class main(object):
       except:
         c4i.logger.error("Exception has occured" ,exc_info=1)
         if fileLogOpen:
-          fLogger.error("xxxxxx: FAILED:: Exception has occured" ,exc_info=1)
+          fLogger.error("C4.100.001: [exception]: FAILED:: Exception has occured" ,exc_info=1)
           c4i.closeFileLog( )
           fileLogOpen = False
         rec.addErr( f, 'ERROR: Exception' )
